@@ -134,9 +134,10 @@ void StopWatch::Layout()
   Control::Layout();
 }
 
-void StopWatch::Draw(int x, int y, size_t w, size_t h)
+void StopWatch::Draw(Lum::OS::DrawInfo* draw,
+                     int x, int y, size_t w, size_t h)
 {
-  Control::Draw(x,y,w,h);
+  Control::Draw(draw,x,y,w,h);
 
   if (!Intersect(x,y,w,h)) {
     return;
@@ -144,8 +145,6 @@ void StopWatch::Draw(int x, int y, size_t w, size_t h)
 
   /* --- */
 
-  Lum::OS::DrawInfo *draw=GetDrawInfo();
-
   draw->PushFont(font,fontStyle);
 
   if (alarm && showInvert) {
